<!DOCTYPE html>
<html lang="zh">
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<style>
html, body {
  height: 100%;
  margin: 0;
  padding: 0;
  overflow: hidden;
}

.background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-image: url('../Pics/Lamia.png');
  background-size: cover;
  background-repeat: no-repeat;
  background-position: center center;
  filter: blur(2px);
  z-index: 1; 
}

.container {
  width: calc(1080px - 50px);
  height: 1920px;
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  padding: 25px 0;
  box-sizing: border-box;
  margin: 0 25px;
  z-index: 2; /* 确保容器在背景之上 */
}

.div-section {
  width: 100%;
  height: calc(25% - 25px);
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.sub-div, .full-div {
  background: rgba(255, 255, 255, 0.8);
  border-radius: 25px;
  backdrop-filter: blur(10px);
}

.sub-div {
  width: 49%;
  height: 100%;
}

.full-div {
  width: 100%;
  height: 100%;
  display: flex; /* 使用Flexbox布局 */
  align-items: center; /* 垂直居中 */
  background: rgba(255, 255, 255, 0.8);
  border-radius: 25px;
  backdrop-filter: blur(10px);
  display: flex;
  flex-direction: column; /* 修改为列方向布局 */
  justify-content: space-between;
}

.pnsIcon {
  z-index: 3; /* 确保图标在所有元素之上 */
  margin-left: 10%;
  width: 200px;
  height: 200px;
}
.flex-vertical-center {
    display: flex;
    align-items: center;
}
.mr-4 {
    margin-right: 8px;
}
.sub-info {
    color: #0a3b85;
    font-weight: 400;
    opacity: .5;
}
.role-info {
    flex: 1;
}
.full-div-header {
  padding-top: 65px;
  display:flex;
}
.full-div-footer {
  display:flex;
}
.level {
  height: 50px;
  font-size: 42px;
  line-height: 48px;
  padding: 4px 8px;
  color: #000000;
  background: linear-gradient(180deg, rgb(255, 238, 1) 0%, rgba(255, 255, 255, .3) 100%);
  border: .8px solid rgba(0, 0, 0, 0.8);
  border-radius: 4px;
}
.full-div-footer .item .number {
    display: flex;
    align-items: center;
    font-size: 50px;
    font-weight: 700;
    color: #2f65da;
}

.full-div-footer .item .title {
    width: 100%;
    color: #000000;
    font-size: 50px;
    font-weight: 500;
    font-family: 'Microsoft YaHei';
    text-align: center;
}
.item {
  /* 添加这些样式以确保内部内容水平居中 */
  display: flex;
  flex-direction: column; /* 使内容垂直排列 */
  justify-content: center; /* 垂直居中 */
  align-items: center; /* 水平居中 */
  height: 100%; /* 确保内容在分配的高度内垂直居中 */
  width: 30%;
  padding-left: 25px;
}
.icon {
  z-index: 3; /* 确保图标在所有元素之上 */
  margin-left: 10%;
  width: 150px;
  height: 150px;
}
.icon-span {
  display: flex;
  align-items: center;
  font-size: 48px;
  font-weight: 700;
  width: 100%;
  color: rgba(38, 38, 41, 0.75);
  font-family: 'Microsoft YaHei';
  align-items: center; /* 水平居中 */
}
.icon-item {
  /* 添加这些样式以确保内部内容水平居中 */
  display: flex;
  flex-direction: column; /* 使内容垂直排列 */
  justify-content: center; /* 垂直居中 */
  align-items: center; /* 水平居中 */
  height: 100%; /* 确保内容在分配的高度内垂直居中 */
  width: 50%;
  padding-left: 25px;
  padding-top: 20%;
  padding-bottom: 20%;
}

</style>
</head>
<body>
<div class="background"></div> <!-- 新增背景层 -->
<div class="container">
  <div class="div-section">
    <div class="full-div">
      <div class="full-div-header" style="width: 100%;height: 50%;">
        <img class="pnsIcon" src="../Pics/pns.png" alt="pns-logo" style="margin-right: 24px;">
        <div>
          <div class="flex-vertical-center">
            <div class="mr-4 text-14 name" style="font-size: 64px;">{{ roleName }}</div>
            <div class="level" style="font-size: 48px;">{{ level }}</div>
          </div>
          <div class="sub-info text-12" style="font-size: 36px; padding-top: 15px;">
            <span>{{ server }} | ID: {{ roleId }}</span>
          </div>
        </div>
        <div>
          <div></div>
        </div>
      </div>
      <div class="full-div-footer" style="width: 100%;height: 50%;">
        <div class="item" style="width: 30%;">
          <span class="number">{{ roleScore }}</span>
          <span class="title">角色总评分</span>
        </div>
        <div class="item">
          <span class="number">{{ roleNum }}</span>
          <span class="title">角色数量</span>
        </div>
        <div class="item">
          <span class="number">{{ fashionCollectionPercent }}</span>
          <span class="title">涂装收集率</span>
        </div>
      </div>
    </div>
  </div>
  <div class="div-section">
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/actionIcon.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">血清数量：</span>
          <span class="icon-span">{{ actionValue }}</span>
          <span class="icon-span">回满时长：</span>
          <span class="icon-span" style="font-size: 32px;">{{ actionRefreshTimeStamp }}</span>
        </div>
      </div>
    </div>
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/blackCard.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">黑卡：</span>
          <span class="icon-span">{{ blackCardNum }}</span>
          <span class="icon-span">研发券：</span>
          <span class="icon-span">{{ developResourceNum }}</span>
        </div>
      </div>
    </div>
  </div>
  <div class="div-section">
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/bossIcon.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">幻痛刷新：</span>
          <span class="icon-span" style="font-size: 32px;">{{ bossRefreshTimeStamp }}</span>
          <span class="icon-span">黑卡：</span>
          <span class="icon-span">{{ bossBlackCard }}</span>
        </div>
      </div>
    </div>
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/transfiniteIcon.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">历战映射：</span>
          <span class="icon-span">{{ transfiniteNum }}</span>
          <span class="icon-span">距离刷新：</span>
          <span class="icon-span" style="font-size: 32px;">{{ transfiniteRefreshTimeStamp }}</span>
        </div>
      </div>
    </div>
  </div>
  <div class="div-section">
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/arenaIcon.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">战区刷新：</span>
          <span class="icon-span" style="font-size: 32px;">{{ arenaRefreshTimeStamp }}</span>
          <span class="icon-span">黑卡：</span>
          <span class="icon-span">{{ arenaBlackCard }}</span>
        </div>
      </div>
    </div>
    <div class="sub-div">
      <div class="" style="display: flex;">
        <img class="icon" src="../Pics/strongHoldIcon.png" alt="pns-logo" style="margin-top: 28%;margin-left: 10%;border-radius: 100%;overflow: hidden;">
        <div class="icon-item">
          <span class="icon-span">诺曼矿区：</span>
          <span class="icon-span">{{ strongHoldRate }}</span>
          <span class="icon-span">距离刷新：</span>
          <span class="icon-span" style="font-size: 32px;">{{ strongHoldTimeStamp }}</span>
        </div>
      </div>
    </div>
  </div>
</div>
</body>
</html>
